@@ -8,8 +8,8 @@
 //! ## How it works
 //!
 //! This uses [serde](https://serde.rs/) to serialize data over unix sockets
-//! via [bincode](https://github.com/servo/bincode). Thanks to the
-//! [`Handle`](https://docs.rs/unix-ipc/latest/unix-ipc/struct.Handle.html) abstraction you can also send any object
+//! via [bincode](https://github.com/bincode-org/bincode). Thanks to the
+//! [`Handle`](crate::serde::Handle) abstraction you can also send any object
 //! across that is convertable into a unix file handle.
 //!
 //! The way this works under the hood is that during serialization and
@@ -19,21 +19,35 @@
 //!
 //! If you only want the unix socket abstraction you can disable all default
 //! features and use the raw channels.
+//!
+//! ## Features
+//!
+//! * `serde`: enables support for the non raw types
+//! * `serde-structural`: enables support for structural data passing
+//! * `bootstrap`: adds support for boostrapping
+//! * `panic-support`: adds support for IPC panic catching
+//! * `backtrace`: adds support for backtraces to panics
 mod raw_channel;
 
 #[cfg(feature = "serde")]
-mod serde;
+pub mod serde;
 
 #[cfg(feature = "serde")]
 mod typed_channel;
 
-#[cfg(feature = "serde")]
+#[cfg(feature = "panic-support")]
+pub mod panic;
+
+#[cfg(feature = "bootstrap")]
 mod bootstrap;
 
 pub use self::raw_channel::*;
 
 #[cfg(feature = "serde")]
-pub use self::{bootstrap::*, serde::*, typed_channel::*};
+pub use self::typed_channel::*;
+
+#[cfg(feature = "bootstrap")]
+pub use self::bootstrap::*;
 
 #[doc(hidden)]
 #[cfg(feature = "serde")]
